@@ -175,12 +175,18 @@ def create_label(
         padding_right = None,
         padding_bottom = None,
         border_width = 0,
-        border_color = "#ffffff",
+        border_color = "#5c5c5c",
         border_radius = 0,
         hover_background_color = "#1e1e1e",
+        hover_border_width = 0,
+        hover_border_color = "#777777",
         pressed_background_color = "#1e1e1e",
+        pressed_border_width = 0,
+        pressed_border_color = "#0078d7",
         disabled_font_color = "#888888",
-        disabled_background_color = "#2d2d2d"
+        disabled_background_color = "#2d2d2d",
+        disabled_border_width = 0,
+        disabled_border_color = "#4a4a4a"
 ):
     label = QLabel(text)
     padding_left_value = padding_left if padding_left is not None else padding
@@ -203,13 +209,16 @@ def create_label(
         }}
         QLabel:hover{{
             background-color: {hover_background_color};
+            border: {hover_border_width}px solid {hover_border_color};
         }}
         QLabel:pressed{{
             background-color: {pressed_background_color};
+            border: {pressed_border_width}px solid {pressed_border_color};
         }}
         QLabel:disabled{{
             color: {disabled_font_color};
             background-color: {disabled_background_color};
+            border: {disabled_border_width}px solid {disabled_border_color};
         }}
     """
     label.setStyleSheet(style)
@@ -244,6 +253,7 @@ def create_button(
     button = QPushButton()
     button.setMaximumWidth(360)
     main_layout = QVBoxLayout(button)
+    main_layout.setContentsMargins(0, 0, 0, 0)
     label = create_label(
         text = text,
         font_size = font_size,
@@ -255,14 +265,27 @@ def create_button(
         padding_top = padding_top,
         padding_right = padding_right,
         padding_bottom = padding_bottom,
+        border_width = border_width,
+        border_color = border_color,
+        border_radius = border_radius,
         hover_background_color = hover_background_color,
+        hover_border_width = hover_border_width,
+        hover_border_color = hover_border_color,
         pressed_background_color = pressed_background_color,
+        pressed_border_width = pressed_border_width,
+        pressed_border_color = pressed_border_color,
         disabled_font_color = disabled_font_color,
-        disabled_background_color = disabled_background_color
+        disabled_background_color = disabled_background_color,
+        disabled_border_width = disabled_border_width,
+        disabled_border_color = disabled_border_color
     )
     label.setAlignment(Qt.AlignmentFlag.AlignCenter)
     label.setWordWrap(True)
     main_layout.addWidget(label)
+    padding_left_value = padding_left if padding_left is not None else padding
+    padding_top_value = padding_top if padding_top is not None else padding
+    padding_right_value = padding_right if padding_right is not None else padding
+    padding_bottom_value = padding_bottom if padding_bottom is not None else padding
     style_sheet = f"""
         QPushButton {{
             font-family: {font_family};
@@ -270,7 +293,6 @@ def create_button(
             color: {font_color};
             font-weight: {font_weight};
             background-color: {background_color};
-            padding: 0px;
             border: {border_width}px solid {border_color};
             border-radius: {border_radius}px;
         }}
